@@ -1,3 +1,7 @@
+"""
+Helper module to find splunk search command usage in app
+"""
+
 from splunk_appinspect.python_analyzer.ast_info_query import Any, MultiOr
 
 
@@ -9,7 +13,7 @@ def find_endpoint_usage(app, kws, regex_file_types):
     return [(<filepath>, <lineno>)...]
     """
     matches_found = app.search_for_patterns(kws, types=regex_file_types)
-    for match_file_and_line, match_object in matches_found:
+    for match_file_and_line, _ in matches_found:
         match_split = match_file_and_line.rsplit(":", 1)
         match_file = match_split[0]
         match_line = match_split[1]
@@ -22,11 +26,15 @@ def find_endpoint_usage(app, kws, regex_file_types):
             query.filter(Any(ast_info.get_literal_string_usage(kw)))
             query.filter(
                 MultiOr(
-                    Any(ast_info.get_module_function_call_usage('urllib2', 'urlopen')),
-                    Any(ast_info.get_module_function_call_usage('requests', 'get')),
-                    Any(ast_info.get_module_function_call_usage('httplib2.Http', 'request')),
+                    Any(ast_info.get_module_function_call_usage("urllib2", "urlopen")),
+                    Any(ast_info.get_module_function_call_usage("requests", "get")),
+                    Any(
+                        ast_info.get_module_function_call_usage(
+                            "httplib2.Http", "request"
+                        )
+                    ),
                 )
             )
             usages = query.collect()
             for usage in usages:
-                yield file_path, usage.lineno
\ No newline at end of file
+                yield file_path, usage.lineno
