@@ -15,7 +15,6 @@ import re
 import sys
 
 import bs4
-from six import iteritems
 import semver
 
 import splunk_appinspect
@@ -287,7 +286,7 @@ def check_authorize_conf_admin_all_objects_privileges(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("authorize.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             authorize_conf_file = app.authorize_conf(dir=directory)
             properties_to_validate = [
@@ -334,7 +333,7 @@ def check_authorize_conf_for_tokens_auth(app, reporter):
     """Check that authorize.conf does not contain a `tokens_auth` stanza"""
     config_file_paths = app.get_config_file_paths("authorize.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             authorize_conf_file = app.authorize_conf(dir=directory)
             for section in authorize_conf_file.sections():
@@ -571,7 +570,7 @@ def check_indexes_conf_only_uses_splunk_db_variable(app, reporter):
 
     config_file_paths = app.get_config_file_paths("indexes.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             indexes_conf_file = app.indexes_conf(directory)
 
@@ -611,7 +610,7 @@ def check_for_index_volume_usage(app, reporter):
 
     config_file_paths = app.get_config_file_paths("indexes.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             indexes_conf_file = app.indexes_conf(directory)
 
@@ -646,7 +645,7 @@ def check_for_inputs_fifo_usage(app, reporter):
     # Please refer to https://jira.splunk.com/browse/ACD-3408 for the logic behind this check.
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_configuration_file = app.inputs_conf(directory)
             fifo_stanzas = [
@@ -671,7 +670,7 @@ def check_inputs_conf_for_tcp(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `tcp` stanza."""
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -696,7 +695,7 @@ def check_inputs_conf_for_splunk_tcp(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -722,7 +721,7 @@ def check_inputs_conf_for_fschange(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -746,7 +745,7 @@ def check_inputs_conf_for_http_global_usage(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -773,7 +772,7 @@ def check_inputs_conf_for_http_local_stanza_usage(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -802,7 +801,7 @@ def check_inputs_conf_for_splunktcptoken(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -831,7 +830,7 @@ def check_inputs_conf_for_batch(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             batch_input_regex_string = r"^batch[:][\/][\/][$]SPLUNK_HOME[/\\]var[/\\]spool[/\\]splunk[/\\][.][.][.]stash(?!_new).+$"
@@ -880,7 +879,7 @@ def check_inputs_conf_batch_has_required_attributes(app, reporter):
         reporter.not_applicable(reporter_output)
         return
 
-    for directory, filename in iteritems(config_file_paths):
+    for directory, filename in iter(config_file_paths.items()):
         file_path = os.path.join(directory, filename)
         inputs_conf = app.inputs_conf(directory)
         for section in inputs_conf.sections():
@@ -902,7 +901,7 @@ def check_inputs_conf_for_udp(app, reporter):
     """Check that inputs.conf does not have any UDP inputs."""
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -925,7 +924,7 @@ def check_inputs_conf_for_ssl(app, reporter):
     """Check that inputs.conf does not have any SSL inputs."""
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -948,7 +947,7 @@ def check_inputs_conf_for_remote_queue_monitor(app, reporter):
     """Check that inputs.conf does not have any remote_queue inputs."""
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -978,7 +977,7 @@ def check_scripted_inputs_cmd_path_pattern(app, reporter):
 
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -1036,7 +1035,7 @@ def check_scripted_inputs_python_version(app, reporter):
 
     config_file_paths = app.get_config_file_paths("inputs.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             inputs_conf = app.inputs_conf(directory)
             for section in inputs_conf.sections():
@@ -1132,7 +1131,7 @@ def check_transforms_conf_for_external_cmd(app, reporter, target_splunk_version)
     """
     config_file_paths = app.get_config_file_paths("transforms.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             transforms_conf = app.transforms_conf(directory)
             external_command_stanzas = [
@@ -1529,7 +1528,7 @@ def check_that_no_configurations_of_default_source_type_in_props_conf(app, repor
     try:
         config_file_paths = app.get_config_file_paths("props.conf")
         if config_file_paths:
-            for directory, filename in iteritems(config_file_paths):
+            for directory, filename in iter(config_file_paths.items()):
                 file_path = os.path.join(directory, filename)
                 props_config = app.props_conf(directory)
                 section_names = props_config.section_names()
@@ -1895,7 +1894,7 @@ def check_for_binary_files_without_source_code(app, reporter):
                         )
                     elif readme_names:
                         readme_find = False
-                        for readme_name, readme_content in iteritems(readmes_dict):
+                        for readme_name, readme_content in iter(readmes_dict.items()):
                             if (
                                 binary_name in readme_content
                                 or "# binary file declaration" in readme_content
@@ -1951,7 +1950,7 @@ def check_that_app_contains_any_windows_specific_components(app, reporter):
         excluded_types = [".ico"]
         # only consider default directory here because local directory will be failed
         inputs_conf_path = os.path.join("default", "inputs.conf")
-        for path, info in iteritems(app.info_from_file):
+        for path, info in iter(app.info_from_file.items()):
             # check if inputs.conf exists
             _, ext = os.path.splitext(path)
             if inputs_conf_path == path:
@@ -2132,9 +2131,7 @@ def check_python_sdk_version(app, reporter):
                 continue
             file_path = os.path.join(directory, file)
             full_file_path = app.get_filename(file_path)
-            match_result = matcher.match_file(
-                filepath=full_file_path
-            )
+            match_result = matcher.match_file(filepath=full_file_path)
             for lineno, result in match_result:
                 splunklib_exists = True
                 file_path = os.path.join(directory, file)
@@ -2143,7 +2140,7 @@ def check_python_sdk_version(app, reporter):
                 try:
                     ver = re.search(ver_rex, result).groups()[0]
                     if len(ver.split(".")) == 2:
-                        ver += ".0" # correct for versions without a patch
+                        ver += ".0"  # correct for versions without a patch
                     parsed_ver = semver.VersionInfo.parse(ver)
                 except Exception as err:
                     reporter_output = (
