@@ -7,8 +7,6 @@ import json
 import logging
 import os
 
-import six
-
 import splunk_appinspect
 
 logger = logging.getLogger(__name__)
@@ -24,12 +22,8 @@ def check_validate_json_data_is_well_formed(app, reporter):
         current_file_relative_path = os.path.join(directory, file_name)
         current_file_full_path = app.get_filename(directory, file_name)
 
-        if six.PY2:
-            with open(current_file_full_path, "r") as f:
-                current_file_contents = f.read()
-        else:
-            with open(current_file_full_path, "r", encoding="utf-8") as f:
-                current_file_contents = f.read()
+        with open(current_file_full_path, "r", encoding="utf-8") as f:
+            current_file_contents = f.read()
 
         try:
             json.loads(current_file_contents)
