@@ -50,9 +50,12 @@ def check_for_hidden_python_files(app, reporter):
 
             byte_string = open(os.path.join(app.app_temp_dir, filepath), "rb").read()
             encoding = chardet.detect(byte_string)["encoding"]
-            content = open(
-                os.path.join(app.app_temp_dir, filepath), "r", encoding=encoding
-            ).read()
+            file_full_path = os.path.join(app.app_temp_dir, filepath)
+            try:
+                content = open(file_full_path, "r", encoding=encoding).read()
+            except UnicodeDecodeError as ex:
+                logger.warning(f"Decoding error: {ex}, file: {file_full_path}")
+                content = open(file_full_path, "r", encoding='utf-8').read()
             content = re.sub("[\r\n]+", " ", content)
 
             # this check only focus on python template code
