@@ -10,7 +10,6 @@ import xml
 from xml.sax import make_parser
 
 import bs4
-import six
 
 import splunk_appinspect
 
@@ -27,9 +26,8 @@ def check_that_all_xml_files_are_well_formed(app, reporter):
     def parse_xml(filename):
         parser = make_parser()
         parser.setContentHandler(xml.sax.handler.ContentHandler())
-        if six.PY3:
-            # Include all external general (text) entities in py3
-            parser.setFeature(xml.sax.handler.feature_external_ges, True)
+        # Include all external general (text) entities in py3
+        parser.setFeature(xml.sax.handler.feature_external_ges, True)
         parser.parse(filename)
 
     for relative_filepath, full_filepath in app.get_filepaths_of_files(types=[".xml"]):
