@@ -1,8 +1,12 @@
 """
 This module implements a simple HTTP server (based on BaseHTTPServer) that serves WSGI applications
 """
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.WEB_SERVER)
@@ -18,4 +22,5 @@ class WSGIServer:
     """
     Create a WSGIServer instance. server_address should be a (host,port) tuple
     """
-    pass
\ No newline at end of file
+
+    pass
