@@ -1,14 +1,19 @@
 """
 Execute xml xmlreader commands
 """
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 class XMLReader:
     """
     xml.sax.xmlreader XMLReader commands
     """
+
     @tags(TagConsts.FILE_READ_AND_WRITE)
     def parse(self):
         """
