@@ -1,8 +1,15 @@
 from enum import Enum
-from splunk_appinspect.python_analyzer.ast_types import AstCallableFunction, AstClass, AstContext, AstVariable, AstModule
+
+from splunk_appinspect.python_analyzer.ast_types import (
+    AstCallableFunction,
+    AstClass,
+    AstContext,
+    AstModule,
+    AstVariable,
+)
+
 
 class Metadata(object):
-
     def __init__(self, name, namespace, description, tags, python_object):
         self.name = name
         self.namespace = namespace
@@ -12,7 +19,7 @@ class Metadata(object):
         assert isinstance(self.namespace, str)
 
         if self.description is None:
-            self.description = ''
+            self.description = ""
         assert isinstance(self.description, str)
         self.description = self.description.strip()
 
@@ -20,7 +27,7 @@ class Metadata(object):
             self.tags = set()
         else:
             # only accept iter collection
-            assert hasattr(tags, '__iter__')
+            assert hasattr(tags, "__iter__")
             self.tags = set(tags)
 
         self.python_object = python_object
@@ -31,23 +38,25 @@ class Metadata(object):
     def instantiate(self):
         pass
 
-class ModuleMetadata(Metadata):
 
+class ModuleMetadata(Metadata):
     def __init__(self, name, namespace, description, tags=None, python_object=None):
         # in case check writer pass a enum as argument
         if isinstance(name, Enum):
             name = name.value
-        super(ModuleMetadata, self).__init__(name, namespace, description, tags, python_object)
+        super(ModuleMetadata, self).__init__(
+            name, namespace, description, tags, python_object
+        )
         self._sub_modules = []
         self._functions = []
         self._classes = []
 
     def __str__(self):
-        return 'Module name: {}, Sub Module names: {}, Function names: {}, Classes: {}'.format(
+        return "Module name: {}, Sub Module names: {}, Function names: {}, Classes: {}".format(
             self.name,
-            ', '.join(map(lambda node: node.name, self._sub_modules)),
-            ', '.join(map(lambda node: node.name, self._functions)),
-            ', '.join(map(lambda node: node.name, self._classes))
+            ", ".join(map(lambda node: node.name, self._sub_modules)),
+            ", ".join(map(lambda node: node.name, self._functions)),
+            ", ".join(map(lambda node: node.name, self._classes)),
         )
 
     def add(self, metadata):
@@ -58,7 +67,7 @@ class ModuleMetadata(Metadata):
         elif isinstance(metadata, ClassMetadata):
             self.classes.append(metadata)
         else:
-            raise Exception('Illegal Metadata types {}'.format(str(type(metadata))))
+            raise Exception("Illegal Metadata types {}".format(str(type(metadata))))
 
     def instantiate(self):
 
@@ -85,9 +94,10 @@ class ModuleMetadata(Metadata):
 
 
 class ClassMetadata(Metadata):
-
     def __init__(self, name, namespace, description, tags=None, python_object=None):
-        super(ClassMetadata, self).__init__(name, namespace, description, tags, python_object)
+        super(ClassMetadata, self).__init__(
+            name, namespace, description, tags, python_object
+        )
         self._functions = []
         self._classes = []
 
@@ -97,7 +107,7 @@ class ClassMetadata(Metadata):
         elif isinstance(metadata, ClassMetadata):
             self._classes.append(metadata)
         else:
-            raise Exception('Illegal metadata type {}'.format(str(type(metadata))))
+            raise Exception("Illegal metadata type {}".format(str(type(metadata))))
 
     def instantiate(self):
 
@@ -105,14 +115,16 @@ class ClassMetadata(Metadata):
         for function in [func for func in self._functions if func.instantiate()]:
             ast_class.function_dict[function.name] = function.instantiate()
         for sub_class in self._classes:
-            ast_class.class_context.variable_map[sub_class.name] = AstVariable(None, {AstVariable.CLASS_TYPE}, sub_class.instantiate())
+            ast_class.class_context.variable_map[sub_class.name] = AstVariable(
+                None, {AstVariable.CLASS_TYPE}, sub_class.instantiate()
+            )
         return ast_class
 
     def __str__(self):
-        return 'Class name: {}, Class names: {}, Function names: {}'.format(
+        return "Class name: {}, Class names: {}, Function names: {}".format(
             self.name,
-            ', '.join(map(lambda node: node.name, self._classes)),
-            ', '.join(map(lambda node: node.name, self._functions))
+            ", ".join(map(lambda node: node.name, self._classes)),
+            ", ".join(map(lambda node: node.name, self._functions)),
         )
 
     @property
@@ -125,37 +137,48 @@ class ClassMetadata(Metadata):
 
     @property
     def module_name(self):
-        return '.'.join(self.namespace.split('.')[: - 1])
+        return ".".join(self.namespace.split(".")[:-1])
 
 
 class FunctionMetadata(Metadata):
-
     def __init__(self, name, namespace, description, tags=None, python_object=None):
-        super(FunctionMetadata, self).__init__(name, namespace, description, tags, python_object)
+        super(FunctionMetadata, self).__init__(
+            name, namespace, description, tags, python_object
+        )
 
     def __str__(self):
-        return 'Function name: {}, function description: {}'.format(self.name, self.description)
+        return "Function name: {}, function description: {}".format(
+            self.name, self.description
+        )
 
     def instantiate(self):
-        python_function_object_in_metadata, function_name, function_namespace = self.python_object, self.name, self.namespace
+        python_function_object_in_metadata, function_name, function_namespace = (
+            self.python_object,
+            self.name,
+            self.namespace,
+        )
 
-        if not hasattr(python_function_object_in_metadata, 'executable'):
+        if not hasattr(python_function_object_in_metadata, "executable"):
             return None
 
         class PythonFunction(AstCallableFunction):
             def __init__(self):
                 AstCallableFunction.__init__(self, function_name, function_namespace)
+
             def action(self, function_node, analyzer, args, keywords, context):
                 # Delegate function call procedure to python function object
                 # Keep user defined function simple, only args and keywords are required positional arguments
                 # other arguments are optional keyword arguments
-                return python_function_object_in_metadata(args,
-                                                 keywords,
-                                                 function_node=function_node,
-                                                 analyzer=analyzer,
-                                                 context=context)
+                return python_function_object_in_metadata(
+                    args,
+                    keywords,
+                    function_node=function_node,
+                    analyzer=analyzer,
+                    context=context,
+                )
+
         return PythonFunction()
 
     @property
     def module_name(self):
-        return '.'.join(self.namespace.split('.')[: - 1])
+        return ".".join(self.namespace.split(".")[:-1])
